@@ -29,7 +29,10 @@ gb_expr_new_boolean (GBBoolean bool)
 GBExpr const *
 gb_expr_new_int (int val)
 {
-	return gb_expr_new_value_doit (gb_value_new_int (val));
+	if (val < 0x7FFF)
+		return gb_expr_new_value_doit (gb_value_new_int (val));
+	else
+		return gb_expr_new_value_doit (gb_value_new_long (val));
 }
 
 GBExpr const *
