@@ -115,7 +115,7 @@ struct _GBExpr {
 };
 
 struct _GBObjRef {   
-	gboolean    method;
+	gboolean    method; /* This flags a_func () */
 	char const *name;
 	GBExprList *parms;
 };
