@@ -17,6 +17,7 @@
 #include "gb-expr.h"
 #include "grammar.h"
 #include "gb-lex.h"
+#include "gb-mmap-lex.h"
 
 #undef GB_LEX_DEBUG
 
@@ -269,6 +270,51 @@ parse_basic (YYSTYPE *res, GBLexerStream *ls, char c)
 			return GB_KEEP_LOOKING;
 		}
 
+	
+		res->v_str = str;
+
+
+		/* See if we have a GB_OBJ_NAME_LPAR */
+		if (gb_lexer_stream_state (ls) == GB_PARSING_INSIDE_SUB &&
+		    gb_lexer_stream_state (ls) != GB_PARSING_INSIDE_DIM) {
+			GBLexerStream *tmp = gb_mmap_stream_copy (ls);
+			int            i;
+
+			while (!gb_lexer_stream_eof (tmp)) {
+				c = gb_lexer_stream_getc (tmp);
+
+				if (c == ' ' || c == '\t') {
+					gb_lexer_stream_getc (ls);
+					continue;
+				} else if (c == '(') {
+			
+					g_free (tmp);
+					
+					if ((i = gb_is_keyword (str, strlen (str))) > 0) {
+						
+						/* 
+						 * Since there are both functions and statements by these names,
+						 * we have to be careful to see if we return a keyword
+						 * or GB_OBJ_NAME_LPAR
+						 */
+						if (g_strcasecmp (str, "Seek") &&
+						    g_strcasecmp (str, "Print") &&
+						    g_strcasecmp (str, "Len")) {
+							g_free (str);
+							return i;
+						}
+					}
+
+					ls->c     = gb_lexer_stream_getc (ls); /* Eat off the '(' */
+					ls->lastc = ' ';
+
+					return GB_OBJ_NAME_LPAR;
+				} else 
+					break;
+			}
+
+		}
+
 		if ((tmp = gb_is_keyword (str, strlen (str))) > 0) {
 #ifdef GB_LEX_DEBUG
 			fprintf (stderr, "Keyword '%s'\n", str);
@@ -277,8 +323,28 @@ parse_basic (YYSTYPE *res, GBLexerStream *ls, char c)
 			
 			return tmp;
 		} 
+				
+
+		/* Check if we have a Goto label */
+		if (gb_lexer_stream_peek (ls) == ':') {
+			GBLexerStream *tmp = gb_mmap_stream_copy (ls);
+			
+			gb_lexer_stream_getc (tmp);
+			
+			while (!gb_lexer_stream_eof (tmp)) {
+				c = gb_lexer_stream_getc (tmp);
+
+				if (c == ' ' || c == '\t') {
+					continue;
+				} else if (c == '\n' || c == '\r') {
+					g_free (tmp);
+					return GB_GOTO_LABEL;
+				} else 
+					return NAME;
+			}					
+			
+		}
 
-		res->v_str = str;
 
 #ifdef GB_LEX_DEBUG
 		fprintf (stderr, "Name : %s\n", str);
@@ -520,7 +586,8 @@ gb_lex_real (gpointer r, GBLexerStream *ls)
 		int            r;
 		
 		switch (s) {
-		case GB_PARSING_BASIC:
+		case GB_PARSING_BASIC: case GB_PARSING_INSIDE_SUB: 
+		case GB_PARSING_INSIDE_DIM:
 			r = parse_basic (res, ls, c);
 			break;
 
@@ -643,7 +710,8 @@ gb_lexer_is_string_char (GBLexerStream *ls, char c)
 	switch (ls->state) {
 
 	case GB_PARSING_ASP:
-	case GB_PARSING_BASIC:
+	case GB_PARSING_BASIC: case GB_PARSING_INSIDE_SUB:
+	case GB_PARSING_INSIDE_DIM:
 		return isalnum ((guchar) c) || c == '_' || c == '$';
 
 	case GB_PARSING_FORM: case GB_PARSING_CLASS:
