@@ -24,12 +24,22 @@ typedef enum {
 	GB_PARSING_BASIC,
 	GB_PARSING_FORM,
 	GB_PARSING_PROJECT,
-	GB_PARSING_CLASS
+	GB_PARSING_CLASS,
+
+	GB_PARSING_ASP,
+
+	GB_PARSING_EXPR,
+	GB_PARSING_STATEMENTS,
+
+	GB_PARSING_INSIDE_SUB,
+	GB_PARSING_INSIDE_DIM
+
 } GBParsingState;
 
 struct _GBLexerStream {
 	GtkObject      object;
 
+	int            first_symbol;
 	int            line;
 	gboolean       incr_line;
 	GBParsingState state;
@@ -51,8 +61,10 @@ struct _GBLexerStreamClass {
 GtkType        gb_lexer_stream_get_type (void);
 GBLexerStream *gb_lexer_stream_new      (void);
 
+
 /* Is this a string character ? */
-gboolean       gb_lexer_is_string_char  (GBLexerStream *ls, char c);
+gboolean       gb_lexer_is_string_char          (GBLexerStream *ls,
+						 char           c);
 
 /* General bits - concrete */
 #define        gb_lexer_stream_line_inc(ls) ((ls)->line++)
