@@ -123,8 +123,7 @@ gb_object_get_type (void)
 }
 
 GBObject *
-gb_object_ref (GBEvalContext  *ec,
-	       GBObject       *object)
+gb_object_ref (GBObject *object)
 {
 	gtk_object_ref (GTK_OBJECT (object));
 
