@@ -65,8 +65,7 @@ GBValue  *gb_object_deref    (GBEvalContext  *ec,
 			      const GBObjRef *ref,
 			      gboolean        try_deref);
 
-GBObject *gb_object_ref      (GBEvalContext  *ec,
-			      GBObject       *object);
+GBObject *gb_object_ref      (GBObject       *object);
 
 #define   gb_object_unref(o) (gtk_object_unref (GTK_OBJECT (o)))
 
