@@ -198,69 +198,67 @@ gb_stmt_new_set (GBParseData  *module,
 
 }
 
-GBSelectCase *
-gb_select_case_new_expr (const GBExpr *expr,
-			 GSList       *statements)
+GBCaseExpr *
+gb_select_case_new_expr (const GBExpr *expr)
 {
-	GBSelectCase *sc = g_new (GBSelectCase, 1);
+	GBCaseExpr *e = g_new (GBCaseExpr, 1);
 
-	sc->type = GB_CASE_EXPR;
-	sc->u.expr = expr;
-	sc->statements = statements;
+	e->type = GB_CASE_EXPR;
+	e->u.expr = expr;
 
-	return sc;
+	return e;
 }
 
-GBSelectCase *
+GBCaseExpr *
 gb_select_case_new_expr_to_expr (const GBExpr *from,
-				 const GBExpr *to,
-				 GSList       *statements)
+				 const GBExpr *to)
 {
-	GBSelectCase *sc = g_new (GBSelectCase, 1);
+	GBCaseExpr *e = g_new (GBCaseExpr, 1);
 
-	sc->type = GB_CASE_EXPR_TO_EXPR;
-	sc->u.expr_to_expr.from = from;
-	sc->u.expr_to_expr.to   = to;
-	sc->statements = statements;
+	e->type = GB_CASE_EXPR_TO_EXPR;
+	e->u.expr_to_expr.from = from;
+	e->u.expr_to_expr.to   = to;
 
-	return sc;
+	return e;
 }
 
-GBSelectCase *
+GBCaseExpr *
 gb_select_case_new_comparison (GBExprType    op,
-			       const GBExpr *to,
-			       GSList       *statements)
+			       const GBExpr *to)
 {
-	GBSelectCase *sc = g_new (GBSelectCase, 1);
+	GBCaseExpr *e = g_new (GBCaseExpr, 1);
 
-	sc->type = GB_CASE_COMPARISON;
-	sc->u.comparison.op = op;
-	sc->u.comparison.to = to;
-	sc->statements = statements;
+	e->type = GB_CASE_COMPARISON;
+	e->u.comparison.op = op;
+	e->u.comparison.to = to;
 
-	return sc;
+	return e;
 }
 
 GBSelectCase *
 gb_select_case_new_else (GSList *statements)
 {
 	GBSelectCase *sc = g_new (GBSelectCase, 1);
+	GBCaseExpr   *e  = g_new (GBCaseExpr, 1);
 
-	sc->type = GB_CASE_ELSE;
+	e->type   = GB_CASE_ELSE;
+	e->u.expr = NULL;
+
+	sc->case_exprs = g_slist_prepend (NULL, (gpointer) e);
 	sc->statements = statements;
-
+	
 	return sc;
 }
 
 GBSelectCase *
-gb_select_case_new_csv (const GBExprList *exprs, GSList *statements)
+gb_select_case_new (GSList *case_exprs,
+		    GSList *statements)
 {
 	GBSelectCase *sc = g_new (GBSelectCase, 1);
 
-	sc->type = GB_CASE_CSV;
-	sc->u.exprs = exprs;
+	sc->case_exprs = case_exprs;
 	sc->statements = statements;
-	
+
 	return sc;
 }
 
@@ -269,17 +267,21 @@ gb_cases_destroy (GSList *l)
 {
 	while (l) {
 		GBSelectCase *sc = l->data;
-
-		if (sc->type == GB_CASE_COMPARISON)
-			gb_expr_destroy (sc->u.comparison.to);
-		else if (sc->type == GB_CASE_EXPR_TO_EXPR) {
-			gb_expr_destroy (sc->u.expr_to_expr.from);
-			gb_expr_destroy (sc->u.expr_to_expr.to);
-		} else if (sc->type == GB_CASE_EXPR)
-			gb_expr_destroy (sc->u.expr);
-
+		GSList       *tmp;
+		
+		for (tmp = sc->case_exprs; tmp; tmp = tmp->next) {
+			GBCaseExpr *e = tmp->data;
+		
+			if (e->type == GB_CASE_COMPARISON)
+				gb_expr_destroy (e->u.comparison.to);
+			else if (e->type == GB_CASE_EXPR_TO_EXPR) {
+				gb_expr_destroy (e->u.expr_to_expr.from);
+				gb_expr_destroy (e->u.expr_to_expr.to);
+			} else if (e->type == GB_CASE_EXPR)
+				gb_expr_destroy (e->u.expr);
+		}
 		gb_stmts_destroy (sc->statements);
-
+		
 		l = g_slist_remove (l, l->data);
 	}
 }
@@ -417,7 +419,7 @@ gb_stmt_new_input (GBParseData *module, const GBExpr *handle,
 
 const GBStatement *
 gb_stmt_new_print (GBParseData *module, const GBExpr *handle,
-		   GBExprList *objrefs)
+		   GBExprList *items)
 {
 	GBStatement *stmt;
 	
@@ -426,7 +428,7 @@ gb_stmt_new_print (GBParseData *module, const GBExpr *handle,
 	stmt = stmt_new (module);
 	stmt->type = GBS_PRINT;
 	stmt->parm.print.handle  = handle;
-	stmt->parm.print.objrefs = objrefs;
+	stmt->parm.print.items = items;
 
 	return stmt;
 }
