@@ -102,7 +102,7 @@ struct _GBStatement {
 		} input;
 		struct {
 			const GBExpr *handle;
-			GBExprList   *objrefs;
+			GBExprList   *items;
 		} print;
 		struct { 
 			const GBExpr *handle;
@@ -215,7 +215,14 @@ void gb_stmt_print  (FILE *sink, const GBStatement *stmt);
 void gb_stmts_print (FILE *sink,
 		     GSList const *stmts, gboolean nest);
 
+/* Select ... Case statement */
+
 struct _GBSelectCase {
+	GSList *case_exprs;
+	GSList *statements;
+};
+
+struct _GBCaseExpr {
 	enum { GB_CASE_EXPR, GB_CASE_EXPR_TO_EXPR,
 	       GB_CASE_COMPARISON, 
 	       GB_CASE_CSV, GB_CASE_ELSE } type;
@@ -231,21 +238,20 @@ struct _GBSelectCase {
 		} comparison;
 		const GBExprList     *exprs;
 	} u;
-	GSList *statements;
 };
 
-GBSelectCase *gb_select_case_new_expr         (const GBExpr *expr,
-					       GSList       *statements);
-GBSelectCase *gb_select_case_new_expr_to_expr (const GBExpr *from,
-					       const GBExpr *to,
-					       GSList       *statements);
-GBSelectCase *gb_select_case_new_comparison   (GBExprType    op,
-					       const GBExpr *to,
-					       GSList       *statements);
-GBSelectCase *gb_select_case_new_else         (GSList       *statements);
+GBCaseExpr *gb_select_case_new_expr         (const GBExpr *expr);
+					 
+GBCaseExpr *gb_select_case_new_expr_to_expr (const GBExpr *from,
+					     const GBExpr *to);
+					 
+GBCaseExpr *gb_select_case_new_comparison   (GBExprType    op,
+					     const GBExpr *to);
 
-GBSelectCase *gb_select_case_new_csv          (const GBExprList *exprs,
-					       GSList       *statements);
+GBSelectCase *gb_select_case_new            (GSList       *case_exprs,
+					     GSList       *statements);
+
+GBSelectCase *gb_select_case_new_else       (GSList       *statements);
 
 /* File handling */
 
