@@ -44,7 +44,7 @@ GBVar      *gb_var_new           (const char    *var_name,
 
 GBConst    *gb_const_new         (GBEvalContext *ec,
 				  const char    *name,
-				  const char    *type,
+				  GtkType        t,
 				  const GBExpr  *expr);
 
 void        gb_const_destroy     (GBConst       *cons);
