@@ -499,8 +499,12 @@ gb_value_print (FILE *sink, const GBValue *v)
 	case GB_VALUE_DATE:
 		g_warning ("Unimplemented");
 		break;
+	case GB_VALUE_OBJECT:
+		fprintf (sink, "Object(%s)",
+			 gtk_type_name (v->gtk_type));
 	default:
-		g_warning ("Too wierd");
+		g_warning ("Too wierd type %d(%s)",
+			   v->gtk_type, gtk_type_name (v->gtk_type));
 		break;
 	}
 }
@@ -525,9 +529,11 @@ gb_value_get_as_double (const GBValue *v)
 		return v->v.byte;
 	case GB_VALUE_BOOLEAN:
 		if (v->v.bool)
-			return 1.0;
+			return -1.0;
 		else
 			return 0.0;
+	case GB_VALUE_EMPTY:
+		return 0.0;
 	default:
 		g_warning ("Unhandled type as double %d",
 			   gb_value_from_gtk_type (v->gtk_type));
@@ -552,6 +558,8 @@ gb_value_get_as_int (const GBValue *v)
 		return (GBInt)v->v.d;
 	case GB_VALUE_BYTE:
 		return (GBInt)v->v.byte;
+	case GB_VALUE_BOOLEAN:
+		return v->v.bool ? -1 : 0;
 	default:
 		g_warning ("Unhandled type as Int");
 		break;
@@ -576,6 +584,8 @@ gb_value_get_as_long (const GBValue *v)
 		return (GBLong)v->v.d;
 	case GB_VALUE_BYTE:
 		return (GBLong)v->v.byte;
+	case GB_VALUE_BOOLEAN:
+		return v->v.bool ? -1 : 0;
 	default:
 		g_warning ("Unhandled type as long");
 		break;
@@ -991,10 +1001,13 @@ gb_value_promote (GBEvalContext *ec,
 		case GB_VALUE_BOOLEAN:
 			/* FIXME: test: is this correct ? */
 			if (v->v.bool)
-				ret = gb_value_new_double (1.0);
+				ret = gb_value_new_double (-1.0);
 			else
 				ret = gb_value_new_double (0.0);
 			break;
+		case GB_VALUE_EMPTY:
+			ret = gb_value_new_double (0.0);
+			break;
 		default:
 			break;
 		}
@@ -1190,9 +1203,6 @@ gb_gtk_type_from_name (const char *vb_type_name)
 
 	g_return_val_if_fail (vb_type_name != NULL, 0);
 
-	if (!g_strcasecmp (vb_type_name, "variant"))
-		return 0;
-
 	name = gb_gtk_type_name (vb_type_name);
 
 	t = gtk_type_from_name (name);
@@ -1224,6 +1234,14 @@ add_type_map (const char *name, GBValue *val)
 	g_hash_table_insert (type_def_hash, GINT_TO_POINTER (val->gtk_type), val);
 }
 
+static void
+add_type_map_type (const char *name, GBValue *val, GtkType gtk_type)
+{
+	g_hash_table_insert (type_hash, g_strdup (name),
+			     GINT_TO_POINTER (gtk_type));
+	g_hash_table_insert (type_def_hash, GINT_TO_POINTER (gtk_type), val);
+}
+
 gint
 gb_strcase_equal (gconstpointer v, gconstpointer v2)
 {
@@ -1313,9 +1331,7 @@ gb_fundamental_type ()
 GtkType
 gb_gtk_type_from_value (GBValueType t)
 {
-	if (t == GB_VALUE_VARIANT)
-		return 0;
-	else if (t >= 0 && t < sizeof (builtin_types) / sizeof (GBBuiltinType))
+	if (t >= 0 && t < sizeof (builtin_types) / sizeof (GBBuiltinType))
 		return builtin_types [t].created_type;
 	else
 		return builtin_types [GB_TYPE_OBJECT].created_type;
@@ -1363,7 +1379,6 @@ gb_type_name_from_gtk (const char *gtk_name)
 void
 gb_value_init (void)
 {
-	GDate *date;
 	int    i;
 	GtkTypeInfo info;
 
@@ -1414,15 +1429,15 @@ gb_value_init (void)
 	add_type_map ("Single",  gb_value_new_single  (0.0));
 	add_type_map ("Double",  gb_value_new_double  (0.0));
 	/* Currency */
-	date = g_date_new_dmy (18, 6, 1977);
-	add_type_map ("Date",    gb_value_new_date_gdate (date));
-	g_date_free (date);
+	
+	add_type_map ("Date",    gb_value_new_time (0,0,0));
 
 	add_type_map ("String",  gb_value_new_string_chars (""));
 	/* Object */
 	/* Error */
 	add_type_map ("Boolean", gb_value_new_boolean (FALSE));
-	add_type_map ("Variant", gb_value_new_int     (0));
+	add_type_map_type ("Variant", gb_value_new_empty (), 
+		builtin_types [GB_VALUE_VARIANT].created_type);
 	/* Data object */
 	/* Decimal */
 	add_type_map ("Byte",    gb_value_new_byte (0));
