@@ -1,4 +1,3 @@
-
 /*
  * GNOME Expression evaluation
  *
@@ -86,6 +85,8 @@ gbrun_eval_context_destroy (GtkObject *o)
 
 	ec = GBRUN_EVAL_CONTEXT (o);
 	if (ec) {
+		GBObject *object;
+		
 		gtk_object_unref (GTK_OBJECT (ec->stack));
 		ec->stack = NULL;
 		gbrun_files_clean (ec);
@@ -96,6 +97,9 @@ gbrun_eval_context_destroy (GtkObject *o)
 		g_free (ec->module);
 
 		while (gbrun_eval_context_proj_pop (ec));
+
+		while ((object = gbrun_eval_context_with_pop (ec)))
+			gb_object_unref (object);
 	}
 
 	GTK_OBJECT_CLASS (gbrun_eval_context_parent)->destroy (o);
@@ -280,6 +284,30 @@ gbrun_eval_context_proj_pop (GBRunEvalContext *ec)
 	return proj;
 }
 
+void
+gbrun_eval_context_with_push (GBRunEvalContext *ec,
+			      GBObject         *object)
+{
+	g_return_if_fail (ec != NULL);
+	g_return_if_fail (object != NULL);
+
+	ec->with = g_slist_prepend (ec->with, gb_object_ref (object));
+}
+
+GBObject *
+gbrun_eval_context_with_pop  (GBRunEvalContext *ec)
+{
+	GBObject *object = NULL;
+	
+	if (!ec || !ec->with)
+		return NULL;
+
+	object = ec->with->data;
+	ec->with = g_slist_remove (ec->with, object);
+
+	return object;
+}
+
 GBValue *
 gbrun_eval_as (GBRunEvalContext  *ec,
 	       const GBExpr      *expr,
