@@ -21,12 +21,11 @@
 #define GBRUN_GLOBAL_GET_CLASS(obj)  (GBRUN_GLOBAL_CLASS (GTK_GLOBAL (obj)->klass))
 
 typedef struct _GBRunGlobalPrivate      GBRunGlobalPrivate;
-typedef struct _GBRunGlobalPrivateClass GBRunGlobalPrivateClass;
 
 struct _GBRunGlobal {
 	GBRunObject parent;
 
-	GSList     *children;
+	GBRunGlobalPrivate *priv;
 };
 
 struct _GBRunGlobalClass {
@@ -35,6 +34,7 @@ struct _GBRunGlobalClass {
 
 GtkType   gbrun_global_get_type (void);
 GBObject *gbrun_global_get      (void);
-void      gbrun_global_add      (GBObject *object);
+void      gbrun_global_add      (GBObject   *object,
+				 const char *name);
 
 #endif /* GBRUN_GLOBAL_H */
