@@ -47,6 +47,10 @@ struct _GBRunObjectClass {
 	GBValue *(*get_arg) (GBRunEvalContext  *ec,
 			     GBRunObject       *object,
 			     int                property);
+
+	GBValue *(*get_ndx) (GBRunEvalContext  *ec,
+			     GBRunObject       *object,
+			     int		index);
 };
 
 typedef enum {
@@ -55,12 +59,24 @@ typedef enum {
 } GBRunPropertyType;
 
 struct _GBRunObjMethod {
-	char             *name;
-	GSList           *args;
-	gint              max_args;
-	gint              min_args;
-	GBRunSecurityFlag mask;
-	gboolean          is_sub;
+	char		*name;
+	gboolean	 is_sub;
+
+	gboolean	 args_parsed;
+	union {
+		struct {
+			GSList		  *args;
+			GtkType            as_type;
+			gint               max_args;
+			gint               min_args;
+			GBRunSecurityFlag  mask;
+		} parsed;
+
+		struct {
+			char		  *args;
+			gboolean	   vararg;
+		} unparsed;
+	} args;
 
 	enum { GBRUN_METHOD_VAR, GBRUN_METHOD_ARG, GBRUN_METHOD_VB } type;
 	union {
@@ -101,6 +117,10 @@ void              gbrun_object_add_variables   (GBRunEvalContext *ec,
 						GBRunObjectClass *klass,
 						GHashTable       *variables);
 
+void              gbrun_object_add_constants   (GBRunEvalContext *ec,
+						GBRunObjectClass *klass,
+						GHashTable       *constants);
+
 void              gbrun_object_add_method_var   (GBRunObjectClass     *klass,
 						 const char           *desc,
 						 GBRunMethodVar       *method);
@@ -131,7 +151,20 @@ void              gbrun_object_init             (GBEvalContext *ec);
 void              gbrun_object_shutdown         (void);
 
 
-#define           gbrun_object_ref(e,o)            (gb_object_ref     (GB_EVAL_CONTEXT (e), GB_OBJECT (o)))
+#define           gbrun_object_ref(o)              (gb_object_ref     (GB_OBJECT (o)))
 #define           gbrun_object_unref(o)            (gb_object_unref   (GB_OBJECT (o)))
 
+typedef struct {
+	GtkType type;
+	int     idx;
+	char   *name;
+	int     flags;
+} GBRunObjectProperty;
+
+GBRunObjectProperty *gbrun_object_get_property (GBRunObjectClass  *klass,
+			   			const char	  *name,
+			   			GBRunObjectClass **on_class,
+			   			GBRunPropertyType  flags);
+
+
 #endif /* GBRUN_OBJECT_H */
