@@ -32,10 +32,18 @@ struct _GBRunProjectClass {
 };
 
 GtkType           gbrun_project_get_type          (void);
+
+void              gbrun_project_register_module   (GBRunProject *project,
+						   GBObject     *object);
+
+void              gbrun_project_deregister_module (GBRunProject *project,
+						   GBObject     *object);
+
 void              gbrun_project_register_object   (GBRunProject *project,
-						   GBRunObject  *object,
-						   const char   *name);
-void              gbrun_project_deregister_object (GBRunProject *project,
+						   const char   *name,
 						   GBRunObject  *object);
 
+void              gbrun_project_deregister_object (GBRunProject *project,
+						   const char   *name);
+
 #endif /* GBRUN_PROJECT_H */
