@@ -18,6 +18,8 @@
 /* for gettimeofday */
 #include <sys/time.h> 
 #include <unistd.h>
+/* for strcmp */
+#include <string.h>
 /* for file I/O */
 #include <gbrun/gbrun-file.h>
 
@@ -381,137 +383,163 @@ gbrun_stmt_erase (GBRunEvalContext  *ec,
 static gboolean
 gbrun_stmt_case (GBRunEvalContext *ec,
 		 GBValue          *val,
-		 GBSelectCase     *c,
+		 GBSelectCase     *sel,
 		 gboolean         *err)
 {
-	gboolean ret = FALSE;
+	GSList      *tmp;
+	gboolean     ret = FALSE;
 
-	g_return_val_if_fail (c != NULL, FALSE);
+	g_return_val_if_fail (sel != NULL, FALSE);
 	g_return_val_if_fail (val != NULL, FALSE);
 
-	switch (c->type) {
-	case GB_CASE_ELSE:
-		ret = TRUE;
-		gbrun_frame_stmts_push (ec, c->statements);
-		*err = FALSE;
-		break;
+	for (tmp = sel->case_exprs; tmp; tmp = tmp->next) {
+		GBCaseExpr  *c = tmp->data;
+		
+		switch (c->type) {
+		case GB_CASE_ELSE:
+			ret = TRUE;
+			gbrun_frame_stmts_push (ec, sel->statements);
+			*err = FALSE;
+			break;
 
-	case GB_CASE_EXPR:
-	{
-		GBValue *v = gb_eval_context_eval (GB_EVAL_CONTEXT (ec),
-						   c->u.expr);
-		if (!v)
-			ret = *err = TRUE;
-		else {
+		case GB_CASE_EXPR:
+		{
+			GBValue *v = gb_eval_context_eval (GB_EVAL_CONTEXT (ec),
+							   c->u.expr);
 			GBBoolean ok;
 
-			if (!gb_eval_compare (GB_EVAL_CONTEXT (ec), v,
-					      GB_EXPR_EQ, val, &ok))
+			if (!v) {
 				ret = *err = TRUE;
+				break;
+			 }
+			
+			if (!gb_eval_compare (GB_EVAL_CONTEXT (ec), v,
+						      GB_EXPR_EQ, val, &ok)) {
+				ret = *err = TRUE;
+				gb_value_destroy (v);
+				break;
+			}	
+			
 			if (ok) {
 				*err = FALSE;
-				gbrun_frame_stmts_push (ec, c->statements);
+				gbrun_frame_stmts_push (ec, sel->statements);
 				ret = TRUE;
+				gb_value_destroy (v);
+				goto finish;
 			}
-			gb_value_destroy (v);
-		}
-		break;
-	}
-	case GB_CASE_EXPR_TO_EXPR:
-	{
-		GBValue   *from, *to;
-		GBBoolean  ok;
-
-		from = gb_eval_context_eval (GB_EVAL_CONTEXT (ec),
-					     c->u.expr_to_expr.from);
-		if (!from) {
-			*err = TRUE;
-			return TRUE;
-		}
-
-		to   = gb_eval_context_eval (GB_EVAL_CONTEXT (ec),
-					     c->u.expr_to_expr.to);
-		if (!to) {
-			gb_value_destroy (from);
-			*err = TRUE;
-			return TRUE;
-		}
-
-		if (!gb_eval_compare (GB_EVAL_CONTEXT (ec), val,
-				      GB_EXPR_GE, from, &ok)) {
-			ret = *err = TRUE;
 			break;
 		}
 		
-		if (ok) {
+		case GB_CASE_EXPR_TO_EXPR:
+		{
+			GBValue   *from, *to;
+			GBBoolean  ok;
+			
+			from = gb_eval_context_eval (GB_EVAL_CONTEXT (ec),
+						     c->u.expr_to_expr.from);
+			if (!from) {
+				*err = ret  = TRUE;
+				break;
+			}
+			
+			to   = gb_eval_context_eval (GB_EVAL_CONTEXT (ec),
+						     c->u.expr_to_expr.to);
+			if (!to) {
+				*err = ret  = TRUE;
+				gb_value_destroy (from);
+				break;
+			}
+			
 			if (!gb_eval_compare (GB_EVAL_CONTEXT (ec), val,
-					      GB_EXPR_LE, to, &ok)) {
+					      GB_EXPR_GE, from, &ok)) {
+				ret = *err = TRUE;
+				gb_value_destroy (from);
+				gb_value_destroy (to);
+				break;
+			}
+			
+			if (ok) {
+				if (!gb_eval_compare (GB_EVAL_CONTEXT (ec), val,
+						      GB_EXPR_LE, to, &ok)) {
+					ret = *err = TRUE;
+					gb_value_destroy (from);
+					gb_value_destroy (to);
+					break;
+				}
+				
+				if (ok) {
+					*err = FALSE;
+					gbrun_frame_stmts_push (ec, sel->statements);
+					ret = TRUE;
+					gb_value_destroy (from);
+					gb_value_destroy (to);
+					goto finish;
+				}
+			}
+			
+			gb_value_destroy (from);
+			gb_value_destroy (to);
+			break;
+	        }
+
+		case GB_CASE_COMPARISON:
+		{
+			GBValue  *to = gb_eval_context_eval (GB_EVAL_CONTEXT (ec),
+							     c->u.comparison.to);
+			GBBoolean ok;
+			
+			if (!to || !gb_eval_compare (GB_EVAL_CONTEXT (ec), val,
+						     c->u.comparison.op, to, &ok)) {
 				ret = *err = TRUE;
 				break;
 			}
 			
 			if (ok) {
 				*err = FALSE;
-				gbrun_frame_stmts_push (ec, c->statements);
+				gbrun_frame_stmts_push (ec, sel->statements);
 				ret = TRUE;
+				gb_value_destroy (to);
+				goto finish;
 			}
+			break;
 		}
-
-		gb_value_destroy (from);
-		gb_value_destroy (to);
-		break;
-	}
-	case GB_CASE_COMPARISON:
-	{
-		GBValue  *to = gb_eval_context_eval (GB_EVAL_CONTEXT (ec),
-						    c->u.comparison.to);
-		GBBoolean ok;
-
-		if (!to || !gb_eval_compare (GB_EVAL_CONTEXT (ec), val,
-					     c->u.comparison.op, to, &ok))
-			ret = *err = TRUE;
-
-		else if (ok) {
-			*err = FALSE;
-			gbrun_frame_stmts_push (ec, c->statements);
-			ret = TRUE;
-			gb_value_destroy (to);
-		}
-		break;
-	}
 	
-	case GB_CASE_CSV:
-        { 
-		const GBExprList *tmp;
-		
-		for (tmp = c->u.exprs; tmp ; tmp = tmp->next) {
-		
-			GBValue *v = gb_eval_context_eval (GB_EVAL_CONTEXT (ec),
-							   tmp->data);
-			if (!v)
-				ret = *err = TRUE;
-			else {
-				GBBoolean ok;
+		case GB_CASE_CSV:
+		{ 
+			const GBExprList *tmp;
+
+			g_warning ("Shouldn't be coming here !");
+
+			for (tmp = c->u.exprs; tmp ; tmp = tmp->next) {
 				
-				if (!gb_eval_compare (GB_EVAL_CONTEXT (ec), v,
-						      GB_EXPR_EQ, val, &ok))
+				GBValue *v = gb_eval_context_eval (GB_EVAL_CONTEXT (ec),
+								   tmp->data);
+				if (!v)
 					ret = *err = TRUE;
-				if (ok) {
-					*err = FALSE;
-					gbrun_frame_stmts_push (ec, c->statements);
-					ret = TRUE;
+				else {
+					GBBoolean ok;
+					
+					if (!gb_eval_compare (GB_EVAL_CONTEXT (ec), v,
+							      GB_EXPR_EQ, val, &ok))
+						ret = *err = TRUE;
+					if (ok) {
+						*err = FALSE;
+						gbrun_frame_stmts_push (ec, sel->statements);
+						ret = TRUE;
+					}
+					gb_value_destroy (v);
 				}
-				gb_value_destroy (v);
 			}
+			break;
 		}
 
-		break;
-	}
-	default:
-		g_warning ("Unimplemented select syntax");
-		break;
+		default:
+			g_warning ("Unimplemented select syntax");
+			break;
+		}
 	}
 
+  finish:	
 	return ret;
 }
 
@@ -521,7 +549,8 @@ gbrun_stmt_for (GBRunEvalContext  *ec,
 		gboolean           init)
 {
 	GBObjRef i;
-	GBValue  *to;
+        GBValue  *to;
+        GBValue  *tmp;
 	GBBoolean ok;
 	gboolean ret=TRUE;
 	
@@ -542,8 +571,8 @@ gbrun_stmt_for (GBRunEvalContext  *ec,
 		gb_value_destroy (from);
 	} else {
 		GBValue *step;
-		GBValue *tmp;
-
+                GBValue *tmp2;
+                
 		if (stmt->parm.forloop.step)
 			step = gb_eval_context_eval (GB_EVAL_CONTEXT (ec),
 						     stmt->parm.forloop.step);
@@ -553,23 +582,30 @@ gbrun_stmt_for (GBRunEvalContext  *ec,
 		if (!step)
 			return FALSE;
 
-		tmp = gb_eval_add (gbrun_objref_deref (ec, NULL, &i, TRUE), step);
+                tmp2 = gbrun_objref_deref (ec, NULL, &i, TRUE);
+		tmp = gb_eval_add (tmp2, step);
 		gbrun_stack_set (ec, i.name, tmp);
 
-		gb_value_destroy (tmp);
+                gb_value_destroy (tmp2);
+                gb_value_destroy (tmp);
 		gb_value_destroy (step);
 	}
 
 	to = gb_eval_context_eval (GB_EVAL_CONTEXT (ec), 
 				   stmt->parm.forloop.to);
-	if (!to ||
-	    !gb_eval_compare (GB_EVAL_CONTEXT (ec),
-			      gbrun_objref_deref (ec, NULL, &i, TRUE),
-			      GB_EXPR_LE, to, &ok)) {
+
+        tmp = gbrun_objref_deref (ec, NULL, &i, TRUE);
+        
+        if (!to ||
+            !gb_eval_compare (GB_EVAL_CONTEXT (ec),
+                              tmp,
+                              GB_EXPR_LE, to, &ok)) {
 		gb_value_destroy (to);
-		return FALSE;
-	}
-	gb_value_destroy (to);
+                gb_value_destroy (tmp);
+                return FALSE;
+        }
+        gb_value_destroy (tmp);
+        gb_value_destroy (to);
 
 	if (ok)
 		gbrun_frame_stmts_push (ec, stmt->parm.forloop.body);
@@ -1014,6 +1050,9 @@ gbrun_stmt_evaluate (GBRunEvalContext *ec, const GBStatement *stmt, gboolean ini
 	case GBS_SEEK:
 		return gbrun_stmt_seek (ec, stmt);
 
+	case GBS_PRINT:
+		return gbrun_stmt_print (ec, stmt);
+
 	case GBS_SET:
 		return gbrun_stmt_set (ec, stmt); 
 
