@@ -15,6 +15,12 @@
 
 struct _GBRunSubFrame {
 	GBRunSubFrame *parent;
+
+	/* Flags that having finished executing
+	   this we need to return and not chew up the
+	   statement stack, to make gbrun_stmts_evaluate
+	   re-enterant */
+	gboolean       eval_call;
 	
 	/* Emulates top / bottom recursion marker */
 	gboolean       init;
