@@ -64,9 +64,10 @@ get_try_list (GBRunEvalContext *ec,
 	if ((proj = gbrun_eval_context_proj_get (ec)))
 		to_try = g_slist_prepend (to_try, proj);
 
-	to_try = g_slist_reverse (to_try);
-
-	/* Do 'With' here */
+ 	to_try = g_slist_reverse (to_try);
+	
+	/* 5. 'With' list */
+	to_try = g_slist_concat (to_try, g_slist_copy (ec->with));
 
 	return to_try;
 }
@@ -100,7 +101,7 @@ gbrun_objref_deref (GBRunEvalContext *ec,
 
 	if (!object)
 		return gbrun_exception_firev (
-			ec, _("No such method / varible '%s'"), ref->name);
+			ec, _("No such method / variable '%s'"), ref->name);
 
 	return gb_object_deref (GB_EVAL_CONTEXT (ec),
 				GB_OBJECT (object),
@@ -216,10 +217,10 @@ gbrun_eval_objref  (GBRunEvalContext *ec,
 	objref = expr->parm.objref;
 	g_return_val_if_fail (objref != NULL, NULL);
 
-	/* FIXME: With ? */
 	object = eval_to_penultimate (ec, objref);
 
-	return gbrun_objref_deref (ec, object, g_slist_last (objref)->data, FALSE);
+	return gbrun_objref_deref (
+		ec, object, g_slist_last (objref)->data, FALSE);
 }
 
 GBValue *
