@@ -36,7 +36,7 @@ GBValue *gbrun_value_promote_name        (GBRunEvalContext *ec,
 					  GBValue          *v,
 					  const char       *type_name);
 
-#define  gbrun_value_copy(ec,v)          (gb_value_copy (GB_EVAL_CONTEXT (ec), (v)))
+#define  gbrun_value_copy(ec,v)          (gb_value_copy ((GBEvalContext *) (ec), (v)))
 
 struct _GBEArray {
 	GSList   *indicees;
@@ -63,4 +63,7 @@ gboolean gbrun_eval_assign            (GBRunEvalContext *ec,
 				       const GSList     *objref,
 				       GBValue          *value);
 
+GBValue *gbrun_value_default_from_var (GBRunEvalContext *ec,
+				       GBVar            *var);
+
 #endif
