@@ -1,18 +1,13 @@
-
 /*
  * GNOME Basic Enterpreter Function registration
  *
  * Authors:
- *    Michael Meeks (mmeeks@gnu.org)
- *    Thomas Meeks  (meekte95@christs-hospital.org.uk)
- *    Ariel Rios    (ariel@arcavia.com)
  *    Sean Atkinson (sca20@cam.ac.uk)
+ *    Ariel Rios    (ariel@arcavia.com)
  *
  * Copyright 2000, Helix Code, Inc.
  */
 
-
-
 #include <sys/time.h>
 #include <unistd.h>
 #include <time.h>
@@ -53,153 +48,170 @@ gbrun_func_date (GBRunEvalContext *ec,
 
 static GBValue *
 gbrun_func_dateadd (GBRunEvalContext *ec,
-		  GBRunObject      *object,
-		  GBValue         **args)
+		    GBRunObject      *object,
+		    GBValue         **args)
 {
 	GString *str;
-	int num;
-	GDate *d;
+	int      num;
+	GDate   *d;
 
-	GB_IS_VALUE(ec, args[0], GB_VALUE_STRING);
-	str = args[0]->v.s;
-	num = gb_value_get_as_int(args[1]);
-	d = gb_value_get_as_gdate(args[2]);
+	GB_IS_VALUE (ec, args [0], GB_VALUE_STRING);
+	str = args [0]->v.s;
+	num = gb_value_get_as_int (args [1]);
+	d = gb_value_get_as_gdate (args [2]);
 
-	if (str->len == 4 && !g_strncasecmp("yyyy", str->str, 4)) { /* year */
+	if (str->len == 4 && !g_strncasecmp ("yyyy", str->str, 4)) { /* year */
 		if (num >= 0)
-			g_date_add_years(d, num);
+			g_date_add_years (d, num);
 		else
-			g_date_subtract_years(d, -num);
-	} else if (str->len == 2 && !g_strncasecmp("ww", str->str, 2)){/*week*/
+			g_date_subtract_years (d, -num);
+
+	} else if (str->len == 2 && !g_strncasecmp ("ww", str->str, 2)) { /* week */
 		if (num >= 0)
-			g_date_add_days(d, 7 * num);
+			g_date_add_days (d, 7 * num);
 		else
-			g_date_subtract_days(d, -7 * num);
+			g_date_subtract_days (d, -7 * num);
+
 	} else if (str->len == 1) {
 		int secs = 0;
 
-		switch (tolower(*str->str)) {
+		switch (tolower ((guchar) *str->str)) {
 		case 'q': /* quarter */
 			num *= 3;
 		case 'm': /* month */
 			if (num >= 0)
-				g_date_add_months(d, num);
+				g_date_add_months (d, num);
 			else
-				g_date_subtract_months(d, num);
+				g_date_subtract_months (d, num);
 			break;
 		case 'y': /* day of year */
 		case 'd': /* day */
 		case 'w': /* weekday */
 			if (num >= 0)
-				g_date_add_days(d, num);
+				g_date_add_days (d, num);
 			else
-				g_date_subtract_days(d, num);
+				g_date_subtract_days (d, num);
 			break;
 		case 'h': /* hour */
-			secs = 60 * 60 * num; break;
+			secs = 60 * 60 * num;
+			break;
 		case 'n': /* minute */
-			secs = 60 * num; break;
+			secs = 60 * num;
+			break;
 		case 's': /* second */
-			secs = num; break;
+			secs = num;
+			break;
 		default:
-			gbrun_exception_fire(ec, "datepart: invalid interval");
+			gbrun_exception_fire (ec, _("datepart: invalid interval"));
 		}
 		if (secs) {
 			GBValue *res;
-			double i, f = modf(args[1]->v.date, &i);
+			double i, f = modf (args [1]->v.date, &i);
 
 			f += 1 + secs / ((double) 24 * 60 * 60);
 			if (f >= 1.0) {
-				g_date_add_days(d, 1);
+				g_date_add_days (d, 1);
 				f -= 1.0;
 			} else if (f <= -1.0) {
-				g_date_subtract_days(d, 1);
+				g_date_subtract_days (d, 1);
 				f += 1.0;
 			}
-			res = gb_value_new_date_gdate(d);
+			res = gb_value_new_date_gdate (d);
 			res->v.date += f;
 			return res;
 		}
 	} else {
-		gbrun_exception_fire(ec, "datepart: invalid interval");
+		gbrun_exception_fire (ec, _("datepart: invalid interval"));
 	}
-	return gb_value_new_date_gdate(d);
+	return gb_value_new_date_gdate (d);
 }
 
-static GBValue *gbrun_func_datepart(GBRunEvalContext *,GBRunObject *,GBValue **);
+static GBValue *gbrun_func_datepart (GBRunEvalContext *, GBRunObject *, GBValue **);
 
 static GBValue *
 gbrun_func_datediff (GBRunEvalContext *ec,
-		   GBRunObject      *object,
-		   GBValue         **args)
+		     GBRunObject      *object,
+		     GBValue         **args)
 {
 	GBValue *date, *ans;
-	GBValue *pargs[4] = {args[0], NULL, args[3], args[4]};
+	GBValue *pargs [4] = { args [0], NULL, args [3], args [4]};
 
-	GB_IS_VALUE(ec, args[1], GB_VALUE_DATE);
-	GB_IS_VALUE(ec, args[2], GB_VALUE_DATE);
+	GB_IS_VALUE (ec, args [1], GB_VALUE_DATE);
+	GB_IS_VALUE (ec, args [2], GB_VALUE_DATE);
 
-	date = gb_value_new_date(args[2]->v.date - args[1]->v.date);
-	pargs[1] = date;
-	ans = gbrun_func_datepart(ec, object, pargs);
-	gb_value_destroy(date);
+	date = gb_value_new_date (args [2]->v.date - args [1]->v.date);
+	pargs [1] = date;
+	ans = gbrun_func_datepart (ec, object, pargs);
+	gb_value_destroy (date);
 
 	return ans;
 }
 
 static GBValue *
 gbrun_func_datepart (GBRunEvalContext *ec,
-		   GBRunObject      *object,
-		   GBValue         **args)
+		     GBRunObject      *object,
+		     GBValue         **args)
 {
 	GDate *d;
 	int ans = 0, firstdayofweek = 1;
 	GString *str;
 
-	GB_IS_VALUE(ec, args[0], GB_VALUE_STRING);
-	str = args[0]->v.s;
-	d = gb_value_get_as_gdate(args[1]);
-	firstdayofweek = gb_value_get_as_int(args[2]);
-	/* FIXME: use fistdayofuear argument in args[3] */
+	GB_IS_VALUE (ec, args [0], GB_VALUE_STRING);
+	str = args [0]->v.s;
+	d = gb_value_get_as_gdate (args [1]);
+	firstdayofweek = gb_value_get_as_int (args [2]);
+	/* FIXME: use fistdayofuear argument in args [3] */
+
+	if (str->len == 4 && !g_strncasecmp ("yyyy", str->str, 4)) /* year */
+		ans = g_date_year (d);
 
-	if (str->len == 4 && !g_strncasecmp("yyyy", str->str, 4)) /* year */
-		ans = g_date_year(d);
 	else if (str->len == 2 && !g_strncasecmp("ww", str->str, 2)) /* week */
 		switch (firstdayofweek) {
 		case 0: /* default (what's an NLS API?) */
 		case 1: /* Sunday */
-			ans = g_date_sunday_week_of_year(d); break;
+			ans = g_date_sunday_week_of_year (d);
+			break;
 		case 2: /* Monday */
-			ans = g_date_monday_week_of_year(d); break;
+			ans = g_date_monday_week_of_year (d);
+			break;
 		case 3: case 4: case 5: case 6: case 7:
-			g_warning("datepart FIXME: support Tuesday-Saturday");
+			g_warning ("datepart FIXME: support Tuesday-Saturday");
 		default:
-			gbrun_exception_fire(ec,"bad first day of week");
+			gbrun_exception_fire(ec,_("bad first day of week"));
 		}
 	else if (str->len == 1)
-		switch (tolower(*str->str)) {
+		switch (tolower ((guchar) *str->str)) {
 		case 'q': /* quarter */
-			ans = 1 + g_date_month(d) / 3; break;
+			ans = 1 + g_date_month (d) / 3;
+			break;
 		case 'm': /* month */
-			ans = g_date_month(d); break;
+			ans = g_date_month (d);
+			break;
 		case 'y': /* day of year */
-			ans = g_date_day_of_year(d); break;
+			ans = g_date_day_of_year (d);
+			break;
 		case 'd': /* day */
-			ans = g_date_day(d); break;
+			ans = g_date_day (d);
+			break;
 		case 'w': /* weekday (FIXME: use firstdayofweek) */
-			ans = g_date_weekday(d); break;
+			ans = g_date_weekday (d);
+			break;
 		case 'h': /* hour */
-			ans = gb_value_time_get_hr(args[1]); break;
+			ans = gb_value_time_get_hr(args [1]);
+			break;
 		case 'n': /* minute */
-			ans = gb_value_time_get_min(args[1]); break;
+			ans = gb_value_time_get_min(args [1]);
+			break;
 		case 's': /* second */
-			ans = gb_value_time_get_sec(args[1]); break;
+			ans = gb_value_time_get_sec(args [1]);
+			break;
 		default:
-			gbrun_exception_fire(ec, "invalid interval character");
+			gbrun_exception_fire (ec, _("invalid interval character"));
 		}
 	else
-		gbrun_exception_fire(ec, "invalid interval string");
-	return gb_value_new_int(ans);
+		gbrun_exception_fire (ec, _("invalid interval string"));
+
+	return gb_value_new_int (ans);
 }
 
 static GBValue *
@@ -218,7 +230,7 @@ gbrun_func_dateserial (GBRunEvalContext *ec,
 		res = gb_value_new_date_gdate (date);
 		g_date_free (date);
 	} else
-		return gbrun_exception_fire (ec, "invalid date");
+		return gbrun_exception_fire (ec, _("invalid date"));
 
 	return res;
 }
@@ -256,7 +268,7 @@ gbrun_func_minute (GBRunEvalContext *ec,
 		 GBValue         **args) 
 {
 	GBValue *res;
-	int      min  = gb_value_time_get_min (args [0]);
+	int      min = gb_value_time_get_min (args [0]);
 
 	res = gb_value_new_int (min);
 	
@@ -391,7 +403,7 @@ gba_datetime_register (GBEvalContext *ec)
 
 	gba_object = gtk_type_new (
 		gbrun_object_subclass_simple (GBRUN_TYPE_OBJECT, ITEM_NAME));
-	gbrun_global_add (GB_OBJECT (gba_object));
+	gbrun_global_add (GB_OBJECT (gba_object), "datetime");
 
 	gba = GBRUN_OBJECT_GET_CLASS (gba_object);
 	
