@@ -12,6 +12,9 @@
 #include <stdlib.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <string.h>
+
+#include <config.h>
 
 #include <gbrun/libgbrun.h>
 #include <gbrun/gbrun.h>
@@ -41,8 +44,8 @@ gbrun_func_vartype (GBRunEvalContext *ec,
 
 static GBValue *
 gbrun_func_filelen (GBRunEvalContext *ec,
-		  GBRunObject      *object,
-		  GBValue         **args)
+		    GBRunObject      *object,
+		    GBValue         **args)
 {
 	char       *name;
 	struct stat buf;
@@ -57,11 +60,23 @@ gbrun_func_filelen (GBRunEvalContext *ec,
 	return gb_value_new_long (buf.st_size);
 }
 
+static GBValue *
+gbrun_func_cint (GBRunEvalContext *ec,
+		 GBRunObject      *object,
+		 GBValue         **args)
+{
+	GBValue *ret;
+
+	ret = gb_value_promote (GB_EVAL_CONTEXT (ec), gb_gtk_type_from_value (GB_VALUE_INT), args [0]);
+
+	return ret;
+
+}
 
 static GBValue *
 gbrun_sub_print (GBRunEvalContext *ec,
-	       GBRunObject      *object,
-	       GSList           *expr)
+		 GBRunObject      *object,
+		 GSList           *expr)
 {
 	for (; expr; expr = expr->next) {
 		GBValue *v;
@@ -173,8 +188,8 @@ gbrun_func_ubound (GBRunEvalContext *ec,
 
 static GBValue *
 gbrun_func_isobject (GBRunEvalContext *ec,
-		    GBRunObject      *object,
-		    GBValue        **args)
+		     GBRunObject      *object,
+		     GBValue        **args)
 {
 	if (!args [0] ||
 	    args [0]->gtk_type != gb_gtk_type_from_value (GB_VALUE_OBJECT))
@@ -199,6 +214,47 @@ gbrun_sub_call_by_name (GBRunEvalContext *ec,
 	return gbrun_objref_deref (ec, GB_OBJECT (object), &ref, TRUE);
 }
 
+#ifdef HAVE_ENVIRON
+extern char **environ;
+#endif
+
+static GBValue *
+gbrun_func_environ (GBRunEvalContext *ec,
+		    GBRunObject      *object,
+		    GBValue        **args)
+{
+	long l;
+	char *name, *end;
+	const char *str;
+
+	GB_IS_VALUE (ec, args [0], GB_VALUE_STRING);
+
+	name = args [0]->v.s->str;
+
+        l = strtol (name, &end, 10);
+	if (*name != '\0' && *end == '\0') { /* A number */
+#ifdef HAVE_ENVIRON
+		int    i;
+		char **s;
+
+		for (i = 0, s = environ; s && *s && i < l; i++)
+			s++;
+		
+		str = *s;
+#else
+		gbrun_exception_firev (
+			ec, "Cannot dump environ by index portably yet");
+		return NULL;
+#endif
+	} else /* name is valid already */
+		str = getenv (name);
+
+	if (!str)
+		return gb_value_new_string_chars ("");
+	else
+		return gb_value_new_string_chars (str);
+}
+
 static GBValue *
 gbrun_func_eval (GBRunEvalContext *ec,
 		 GBRunObject      *object,
@@ -239,7 +295,7 @@ gba_func_register (GBEvalContext *ec)
 	gbrun_object_add_method_arg (gba, "func;vartype;a,variant;integer;n",
 				     gbrun_func_vartype);
         
-	gbrun_object_add_method_arg (gba, "func;filelen;pathname,string;string;i",
+	gbrun_object_add_method_arg (gba, "func;filelen;pathname,string;long;i",
 				     gbrun_func_filelen);
 
 	gbrun_object_add_method_arg (gba, "func;eof;filenumber,integer;boolean;i",
@@ -278,6 +334,15 @@ gba_func_register (GBEvalContext *ec)
 	gbrun_object_add_method_arg (gba, "func;ubound;arrayname,variant;dimension,long,byval,1;long;n",
 				     gbrun_func_ubound);
 
+	gbrun_object_add_method_arg (gba, "func;cint;expression,variant;integer;n",
+				     gbrun_func_cint);
+
+	/* FIXME: is this a security thing ? */
+	gbrun_object_add_method_arg (gba, "func;environ;var,string;string;n",
+				     gbrun_func_environ);
+	gbrun_object_add_method_arg (gba, "func;environ$;var,string;string;n",
+				     gbrun_func_environ);
+
 	/* Possibly only valid for vbscript etc. */
         gbrun_object_add_method_arg (gba, "func;eval;basic,string;variant;n",
 				     gbrun_func_eval);
