@@ -105,9 +105,9 @@ gbrun_func_log (GBRunEvalContext *ec,
 	GBDouble d = gb_value_get_as_double (args [0]);
 
 	if (!d)
-		return gbrun_exception_fire  (ec, "Log error: infinite result");
+		return gbrun_exception_fire  (ec, _("Log error: infinite result"));
 	else if (d <= 1)
-		return gbrun_exception_fire  (ec, "Log error: NAN");
+		return gbrun_exception_fire  (ec, _("Log error: NAN"));
 	else
 		return gb_value_new_double (log (d));
 }
@@ -200,7 +200,7 @@ gba_math_register (GBEvalContext *ec)
 
 	gba_object = gtk_type_new (
 		gbrun_object_subclass_simple (GBRUN_TYPE_OBJECT, ITEM_NAME));
-	gbrun_global_add (GB_OBJECT (gba_object));
+	gbrun_global_add (GB_OBJECT (gba_object), "math");
 
 	gba = GBRUN_OBJECT_GET_CLASS (gba_object);
 
