@@ -245,9 +245,14 @@ gbrun_func_mid (GBRunEvalContext *ec,
 	int last;
 	GBValue *ans;
        	GString *str;	
-	GBInt start  = gb_value_get_as_int (args [1]);
+	GBInt start  = gb_value_get_as_int (args [1]) - 1;
 	GBInt length = gb_value_get_as_int (args [2]);
 
+	if (start == -1)
+		start = 0; /* Wierd, but hey */
+	else if (start < 0)
+		return gbrun_exception_firev (ec, _("invalid string offset %d"), start);
+
 	GB_IS_VALUE (ec, args [0], GB_VALUE_STRING);
 	str = args [0]->v.s;
 
@@ -274,9 +279,14 @@ gbrun_func_midb (GBRunEvalContext *ec,
 	int last;
 	GBValue *ans;
        	GString *str;	
-	GBInt start  = gb_value_get_as_int (args [1]);
+	GBInt start  = gb_value_get_as_int (args [1]) - 1;
 	GBInt length = gb_value_get_as_int (args [2]);
 
+	if (start == -1)
+		start = 0; /* Wierd, but hey */
+	else if (start < 0)
+		return gbrun_exception_firev (ec, _("invalid string offset %d"), start);
+
 	GB_IS_VALUE (ec, args [0], GB_VALUE_STRING);
 	str = args [0]->v.s;
 
