@@ -195,6 +195,10 @@ form_item_setarg (GBRunEvalContext *ec,
 		fi->tag = g_strdup (val->v.s->str);
 		return TRUE;
 
+	case DRAGMODE:
+		fi->dragmode = val->v.i;
+		return TRUE;
+
 	default:
 		g_warning ("form_item: Set of unhandled property '%s'", p_name[property]);
 		return FALSE;
@@ -281,6 +285,9 @@ form_item_getarg (GBRunEvalContext *ec,
 	case TAG:
 		return gb_value_new_string_chars (fi->tag);
 
+	case DRAGMODE:
+		return gb_value_new_int (fi->dragmode);
+
 	default:
 		g_warning ("form_item: Get of unhandled property '%s'", p_name[property]);
 		break;
@@ -392,10 +399,20 @@ gbrun_form_item_invoke (GBRunEvalContext *ec,
 	fi = gtk_object_get_data (GTK_OBJECT (w), GBRUN_FORM_ITEM_KEY);
 	g_return_if_fail (GBRUN_IS_FORM_ITEM (fi));
 
-	fn_name = g_strconcat (fi->name, suffix, NULL);;
+	fn_name = g_strconcat (fi->name, suffix, NULL);
 
-	gbrun_form_invoke (ec, GBRUN_FORM (fi->parent), fn_name, fi);
+	if (GBRUN_IS_FORM (fi->parent)) {
+		gbrun_form_invoke (ec, GBRUN_FORM (fi->parent), fn_name, fi);
 
+	} else if (GBRUN_IS_FORM_ITEM (fi->parent)) {
+		GBRunFormItem	*fi2;
+		
+		fi2 = GBRUN_FORM_ITEM (fi->parent);
+		if (GBRUN_IS_FORM (fi2->parent)) {
+			gbrun_form_invoke (ec, GBRUN_FORM (fi2->parent), fn_name, fi);
+		}
+	}
+	
 	g_free (fn_name);
 }
 
@@ -509,7 +526,16 @@ gbrun_form_subitem_add_virtual (GBRunEvalContext *ec,
 			        GBRunForm        *to_form,
 			        const char       *name)
 {
-	return;
+	g_return_if_fail (subitem != NULL);
+	g_return_if_fail (item    != NULL);
+	g_return_if_fail (name    != NULL);
+	g_return_if_fail (to_form != NULL);
+
+	subitem->parent = GBRUN_OBJECT (item);
+	subitem->name   = g_strdup (name);
+	
+	/* FIXME : Is something supposed to be done with to_form ? */
+
 }
 
 /**
