@@ -288,6 +288,36 @@ form_setarg (GBRunEvalContext *ec,
 		form->scalemode = val->v.i;
 		return TRUE;
 
+	case LINK_TOPIC:
+		form->linktopic = g_strdup (val->v.s->str);
+		return TRUE;
+	
+	/* FIXME : Need to actually honour these settings */
+	case STARTUP_POSITION:
+		form->startup_pos = val->v.i;
+		return TRUE;
+
+        case MAX_BUTTON:
+		form->maxbutton = (val->v.i == VB_TRUE);
+		return TRUE;
+	      
+	case MIN_BUTTON:
+		form->minbutton = (val->v.i == VB_TRUE);
+		return TRUE;
+
+	case SHOW_IN_TASKBAR:
+		form->show_in_taskbar = (val->v.i == VB_TRUE);
+		return TRUE;
+			
+	case BORDER_STYLE:
+		form->borderstyle = val->v.i;
+		return TRUE;
+
+	case CONTROLBOX:
+		form->controlbox = (val->v.i == VB_TRUE);
+		return TRUE;
+
+			
 	default:
 		g_warning ("form: Set of unhandled property '%s'", p_name[property]);
 		return FALSE;
@@ -337,6 +367,28 @@ form_getarg (GBRunEvalContext *ec,
 
 	case TAG: 
 		return gb_value_new_string_chars (form->tag);
+		
+        case LINK_TOPIC:
+		return gb_value_new_string_chars (form->linktopic);
+	     
+        case STARTUP_POSITION:
+		return gb_value_new_int (form->startup_pos);
+		
+	case MAX_BUTTON:
+		return gb_value_new_boolean (form->maxbutton);
+
+        case MIN_BUTTON:
+		return gb_value_new_boolean (form->minbutton);
+
+	case SHOW_IN_TASKBAR:
+		return gb_value_new_boolean (form->show_in_taskbar);
+
+	case BORDER_STYLE:
+		return gb_value_new_int (form->borderstyle);
+
+	case CONTROLBOX:
+		return gb_value_new_boolean (form->controlbox);
+
 
 	default:
 		g_warning ("form: get of unhandled property '%s'", p_name[property]);
@@ -441,9 +493,10 @@ gbrun_form_show (GBRunForm *form)
 {
 	g_return_if_fail (GBRUN_IS_FORM (form));
 
-	gtk_widget_show_all (GTK_WIDGET (form->window));
+	gtk_widget_show (GTK_WIDGET (form->window));	
 }
 
+
 void
 gbrun_form_add (GBRunForm         *form,
 		GBRunFormItem     *item,
@@ -465,9 +518,9 @@ gbrun_form_invoke (GBRunEvalContext *ec,
 		   const char       *method,
 		   GBRunFormItem    *fi)
 {
-	GBExpr	 *expr = NULL;
-	GBValue  *ignore;
-	gboolean  ret;
+	const GBExpr	*expr = NULL;
+	GBValue  	*ignore;
+	gboolean	 ret;
 	
 	g_return_val_if_fail (form != NULL, FALSE);
 
@@ -481,7 +534,7 @@ gbrun_form_invoke (GBRunEvalContext *ec,
 		if (fi) {
 			if (fi->index >= 0) {
 				expr = gb_expr_new_int (fi->index);
-				ref.parms = g_slist_append (ref.parms, expr);
+				ref.parms = g_slist_append (ref.parms, (gpointer) expr);
 			}
 		}
 
@@ -506,11 +559,11 @@ gbrun_form_invoke (GBRunEvalContext *ec,
 	return ret;
 }
 
-	typedef struct {
-		char		*name;
-		char		*type;
-		GBRunFormItem	*item;
-	} GBFormItemSib;
+typedef struct {
+	char		*name;
+	char		*type;
+	GBRunFormItem	*item;
+} GBFormItemSib;
 		
 /**
  * gbrun_form_init:
@@ -801,6 +854,9 @@ gbrun_form_instance_init (GBRunForm *form)
 				    form->accel_group);
 
 	form->radio_btn = NULL;
+	
+	gtk_widget_show (GTK_WIDGET (vbox));
+	gtk_widget_show (GTK_WIDGET (form->fixed));
 }
 
 static void
