@@ -39,13 +39,26 @@ static gboolean frame_setarg (GBRunEvalContext *ec,
 			      int	        property,
 			      GBValue	      *val);
 
+static GtkFixed *gbrun_frame_get_fixed (GBRunEvalContext *ec,
+				        GBRunFormItem    *item);
+
+static gboolean gbrun_frame_get_radio_btn (GBRunEvalContext *ec,
+				           GBRunFormItem    *item,
+				           GtkWidget        **radio_btn);
+
+static void gbrun_frame_set_radio_btn (GBRunEvalContext *ec,
+				       GBRunFormItem    *item,
+				       GtkWidget        *radio_btn);
+
 /*
  * Note: GBRunFrame already exists in ../gbrun.h
  */
 typedef struct {
-	GBRunFormItem    item;
+	GBRunFormItem		 item;
 
-	GtkJustification alignment;
+	GtkFixed		*fixed;
+	GtkJustification	 alignment;
+	GtkWidget		*radio_btn;
 } GBRunFramed;
 
 
@@ -73,7 +86,7 @@ gbrun_frame_construct (GBRunEvalContext *ec,
 	GBRunFramed *dest = GBRUN_FRAMED (item);
 
 #ifdef DEBUG_FR
-	printf ("gbrun_frame_construct entered.\n");
+	printf ("Enter gbrun_frame_construct.\n");
 #endif
 	w = gtk_frame_new ("");
 	gbrun_form_item_set_widget (GBRUN_FORM_ITEM (dest), w);
@@ -83,6 +96,14 @@ gbrun_frame_construct (GBRunEvalContext *ec,
 
 	dest->alignment = GTK_JUSTIFY_LEFT;
 	gtk_frame_set_label_align (GTK_FRAME (w), GTK_JUSTIFY_LEFT, 0.2);
+
+	dest->fixed = GTK_FIXED (gtk_fixed_new ());
+	gtk_container_add (GTK_CONTAINER (w), GTK_WIDGET (dest->fixed));
+#ifdef DEBUG_FR
+	printf ("      fixed is at %#x\n", dest->fixed);
+#endif
+	
+	dest->radio_btn = NULL;
 }
 
 
@@ -98,7 +119,7 @@ gbrun_frame_class_init (GBRunObjectClass *klass)
 	GBRunFormItemClass	*form_class = (GBRunFormItemClass *) klass;
 
 #ifdef DEBUG_FR
-	printf ("gbrun_frame_class_init entered.\n");	
+	printf ("Enter gbrun_frame_class_init.\n");	
 #endif
 	
 	klass->set_arg = frame_setarg;
@@ -108,9 +129,13 @@ gbrun_frame_class_init (GBRunObjectClass *klass)
 
 	gbrun_object_add_property (klass, "caption",   gb_type_string, CAPTION);
 
-	form_class->construct = gbrun_frame_construct;
+	form_class->construct     = gbrun_frame_construct;
 
-	gtk_class->destroy    = gbrun_frame_destroy;
+	form_class->get_fixed     = gbrun_frame_get_fixed;
+	form_class->get_radio_btn = gbrun_frame_get_radio_btn;
+	form_class->set_radio_btn = gbrun_frame_set_radio_btn;
+
+	gtk_class->destroy        = gbrun_frame_destroy;
 
 }
 
@@ -125,7 +150,7 @@ gbrun_frame_get_type (void)
 	static GtkType object_type = 0;
 
 #ifdef DEBUG_FR
-	printf ("gbrun_frame_get_type entered.\n");
+	printf ("Enter gbrun_frame_get_type.\n");
 #endif
 	if (!object_type) {
 		static const GtkTypeInfo object_info = {
@@ -168,7 +193,7 @@ frame_setarg (GBRunEvalContext *ec,
 	                     gbrun_form_item_get_widget (GBRUN_FORM_ITEM  (object)));
 
 #ifdef DEBUG_FR
-	printf ("frame_setarg entered.\n");
+	printf ("Enter frame_setarg\n");
 #endif
 	g_return_val_if_fail (frame != NULL, FALSE);
 
@@ -176,7 +201,7 @@ frame_setarg (GBRunEvalContext *ec,
 	case ALIGNMENT:
 	{
 #ifdef DEBUG_FR
-		printf ("frame_setarg: ALIGNMENT\n");
+		printf ("      ALIGNMENT\n");
 #endif
 		switch (val->v.i) {
 			case VB_LEFT_JUSTIFY:
@@ -203,7 +228,7 @@ frame_setarg (GBRunEvalContext *ec,
 
 	case CAPTION: {
 #ifdef DEBUG_FR
-		printf ("frame_setarg: CAPTION\n");
+		printf ("      CAPTION\n");
 #endif
 		gtk_frame_set_label (w, val->v.s->str);
 		return TRUE;
@@ -232,7 +257,7 @@ frame_getarg (GBRunEvalContext *ec,
 	                     gbrun_form_item_get_widget (GBRUN_FORM_ITEM (object)));
 
 #ifdef DEBUG_FR
-	printf ("frame_getarg entered.\n");
+	printf ("Enter frame_getarg.\n");
 #endif
 	g_return_val_if_fail (frame != NULL, NULL);
 
@@ -249,6 +274,61 @@ frame_getarg (GBRunEvalContext *ec,
 	}
 }
 
+/**
+ * gbrun_frame_get_fixed
+ *   @ec
+ *   @item
+ **/
+static GtkFixed *gbrun_frame_get_fixed (GBRunEvalContext *ec,
+				        GBRunFormItem    *item)
+{
+	GBRunFramed *frame = GBRUN_FRAMED (item);
+
+#ifdef DEBUG_FR
+	printf ("Enter gbrun_frame_get_fixed.\n");
+#endif
+	return frame->fixed;
+}
+
+/**
+ * gbrun_frame_get_radio_btn
+ *   @ec
+ *   @item
+ *   @radio_btn
+ **/
+static gboolean gbrun_frame_get_radio_btn (GBRunEvalContext *ec,
+				           GBRunFormItem    *item,
+				           GtkWidget        **radio_btn)
+{
+	GBRunFramed *frame = GBRUN_FRAMED (item);
+
+#ifdef DEBUG_FR
+	printf ("Enter gbrun_frame_get_radio_btn.\n");
+#endif
+	*radio_btn = frame->radio_btn;
+	
+	return TRUE;
+}
+
+/**
+ * gbrun_frame_set_radio_btn
+ *   @ec
+ *   @item
+ *   @radio_btn
+ **/
+static void gbrun_frame_set_radio_btn (GBRunEvalContext *ec,
+				       GBRunFormItem    *item,
+				       GtkWidget        *radio_btn)
+{
+	GBRunFramed *frame = GBRUN_FRAMED (item);
+
+#ifdef DEBUG_FR
+	printf ("Enter gbrun_frame_set_radio_btn.\n");
+#endif
+	frame->radio_btn = radio_btn;
+	
+	return;
+}
 
 /**
  * gbrun_frame_register
