@@ -177,6 +177,9 @@ gbrun_menu_add (GBRunEvalContext *ec,
 	/* Attach it to the menubar */
 	gtk_menu_bar_append (menubar, GTK_WIDGET (menuitem));
 	gtk_widget_show_all (GTK_WIDGET (menuitem));
+	
+	gtk_widget_show (GTK_WIDGET (menubar));
+
 }
 
 static void
@@ -194,6 +197,7 @@ gbrun_menu_addsub (GBRunEvalContext *ec,
 	if (! dest->submenu) {
 		dest->submenu = gtk_menu_new();
 		gtk_menu_item_set_submenu (GTK_MENU_ITEM (item->widget), dest->submenu);
+		gtk_widget_show (dest->submenu);
 	}
 
 	gtk_menu_append (GTK_MENU (dest->submenu), subitem->widget);
