@@ -11,7 +11,7 @@
 #include "gbrun-form-item.h"
 #include <gnome.h>
 
-#define ITEM_NAME "gb-vb.pixturebox"
+#define ITEM_NAME "gb-vb.picturebox"
 
 
 enum {
