@@ -80,7 +80,7 @@ timer_setarg (GBRunEvalContext *ec,
 	}
 
 	default:
-		g_warning ("Unhandled property '%d'", property);
+		g_warning ("timer: Unhandled property '%d'", property);
 		return FALSE;
 	}
 }
@@ -106,7 +106,7 @@ timer_getarg (GBRunEvalContext *ec,
 		return gb_value_new_long (timer->interval);
 
 	default:
-		g_warning ("Unhandled property '%d'", property);
+		g_warning ("timer: Unhandled property '%d'", property);
 		return NULL;
 	}
 }
